@@ -18,12 +18,3 @@ test_that("get_data.mapbayests works", {
   expect_length(data_list <- get_data(est001, output = "list"), 8)
   expect_equal(data_list[[1]], filter(get_data(est001, output = "df"), ID == 1))
 })
-
-test_that("see_data is deprecated", {
-  expect_warning(see_mod1 <- see_data(moddata1), "see_data\\(\\) is deprecated. Use get_data\\(\\) instead.")
-  expect_equal(see_mod1, get_data(moddata1))
-
-  expect_warning(see_est1 <- see_data(est001), "see_data\\(\\) is deprecated. Use get_data\\(\\) instead.")
-  expect_equal(see_est1, get_data(est001))
-})
-
